@@ -1,3 +1,5 @@
+knots <- function(Fn, ...)UseMethod('knots')
+
 knots.basisfd <- function(Fn, interior = TRUE, ...) {
 ##
 ## 1.  object$type = 'bspline'?
@@ -5,7 +7,7 @@ knots.basisfd <- function(Fn, interior = TRUE, ...) {
   type <- Fn$type
   oName <- substring(deparse(substitute(Fn)), 1, 33)
   if(is.null(type))
-    stop('is.null((', oName, ')$type);  must be "bspline"') 
+    stop('is.null((', oName, ')$type);  must be "bspline"')
   if(type != 'bspline')
     stop('(', oName, ')$type) = ', type[1], ';  must be "bspline"')
 ##
@@ -15,9 +17,9 @@ knots.basisfd <- function(Fn, interior = TRUE, ...) {
   if(interior) return(int)
 #
   nord <- norder(Fn)
-  rng <- Fn$rangeval 
+  rng <- Fn$rangeval
   allKnots <- c(rep(rng[1], nord), int, rep(rng[2], nord))
-  return(allKnots) 
+  return(allKnots)
 }
 
 knots.fd <- function(Fn, interior=TRUE, ...){
@@ -25,4 +27,4 @@ knots.fd <- function(Fn, interior=TRUE, ...){
 }
 knots.fdSmooth <- function(Fn, interior=TRUE, ...){
   knots(Fn$fd, interior=interior, ...)
-} 
+}
